"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDebouncedValueChangedIndicator = useDebouncedValueChangedIndicator;
exports.handleRefFocusState = handleRefFocusState;

var _react = require("react");

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function useDebouncedValueChangedIndicator(value, delay) {
  var _useState = (0, _react.useState)(false),
      _useState2 = _slicedToArray(_useState, 2),
      isDirty = _useState2[0],
      setIsDirty = _useState2[1];

  (0, _react.useEffect)(function () {
    if (value === '') {
      setIsDirty(false);
    } // Set debouncedValue to value (passed in) after the specified delay


    var handler = setTimeout(function () {
      if (value !== '') {
        setIsDirty(true);
      }
    }, delay);
    return function () {
      clearTimeout(handler);
    };
  }, [value]);
  return isDirty;
} // Inspired by https://medium.com/@teh_builder/ref-objects-inside-useeffect-hooks-eb7c15198780


function handleRefFocusState(ref, setIsFocused) {
  var focusListener = function focusListener() {
    return setIsFocused(true);
  };

  var blurListener = function blurListener() {
    return setIsFocused(false);
  };

  return (0, _react.useCallback)(function (node) {
    if (ref.current) {
      var current = ref.current;
      current.removeEventListener('focus', focusListener);
      current.removeEventListener('blur', blurListener);
    }

    if (node) {
      node.addEventListener('focus', focusListener);
      node.addEventListener('blur', blurListener);
    }

    ref.current = node;
  }, []);
}
//# sourceMappingURL=hooks.js.map